import './polyfills';
import * as Sentry from "@sentry/react";

// Initialize Sentry as early as possible
Sentry.init({
  dsn: import.meta.env.VITE_SENTRY_DSN,
  environment: import.meta.env.VITE_SENTRY_ENVIRONMENT || 'development',
  release: import.meta.env.VITE_SENTRY_RELEASE || '1.0.0',
  
  // Performance Monitoring
  tracesSampleRate: parseFloat(import.meta.env.VITE_SENTRY_TRACES_SAMPLE_RATE || '0.1'),
  
  // Session Replay
  replaysSessionSampleRate: 0.1, // This sets the sample rate at 10%. You may want to change it to 100% while in development and then sample at a lower rate in production.
  replaysOnErrorSampleRate: 1.0, // If you're not already sampling the entire session, change the sample rate to 100% when sampling sessions where errors occur.
  
  integrations: [
    Sentry.browserTracingIntegration(),
    Sentry.replayIntegration({
      // Mask all text content, record only clicks, inputs, and navigation
      maskAllText: true,
      blockAllMedia: true,
    }),
  ],
  
  // Filter sensitive data before sending to Sentry
  beforeSend(event, _hint) {
    // Remove sensitive data from error context
    if (event.extra) {
      delete event.extra.password;
      delete event.extra.token;
      delete event.extra.apiKey;
      delete event.extra.accessToken;
      delete event.extra.secret;
      delete event.extra.authorization;
    }
    
    // Filter sensitive request data
    if (event.request) {
      if (event.request.headers) {
        delete event.request.headers.authorization;
        delete event.request.headers.Authorization;
        delete event.request.headers['x-api-key'];
        delete event.request.headers['X-API-Key'];
      }
    }
    
    return event;
  },
  
  // Set default tags for all events
  initialScope: {
    tags: {
      component: 'browser-example',
      environment: import.meta.env.VITE_SENTRY_ENVIRONMENT || 'development'
    }
  }
});

import React from 'react'
import ReactDOM from 'react-dom/client'
import { App } from './App'
import ErrorBoundary from './components/ErrorBoundary';
import './index.css'
import { AuthProvider } from "react-oidc-context"
import awsConfig from './aws-exports'
import { enableAutoHealthCheck } from './utils/deploymentHealthCheck'

const cognitoAuthConfig = {
  authority: `https://cognito-idp.${awsConfig.Auth.region}.amazonaws.com/${awsConfig.Auth.userPoolId}`,
  client_id: awsConfig.Auth.userPoolWebClientId,
  redirect_uri: awsConfig.Auth.oauth.redirectSignIn,
  response_type: "code",
  scope: awsConfig.Auth.oauth.scope.join(" "),
}

// Global error handler for chunk loading failures
window.addEventListener('error', (event) => {
  const error = event.error;
  const message = event.message || '';
  
  // Check if this is a chunk loading error
  if (
    message.includes('Loading chunk') ||
    message.includes('Failed to fetch dynamically imported module') ||
    (error && error.message && (
      error.message.includes('Loading chunk') ||
      error.message.includes('Failed to fetch dynamically imported module') ||
      error.message.includes('ChunkLoadError')
    ))
  ) {
    console.warn('🔄 Chunk loading failed, attempting recovery...', {
      message,
      error: error?.message,
      stack: error?.stack
    });
    
    // Clear all caches and reload to get fresh chunks
    if ('caches' in window) {
      caches.keys().then(names => {
        names.forEach(name => caches.delete(name));
      }).finally(() => {
        (window as any).location.reload();
      });
    } else {
      (window as any).location.reload();
    }
    
    // Prevent the error from propagating
    event.preventDefault();
    return true;
  }
});

// Handle unhandled promise rejections for import() failures
window.addEventListener('unhandledrejection', (event) => {
  const reason = event.reason;
  
  if (
    reason &&
    (reason.message?.includes('Failed to fetch dynamically imported module') ||
     reason.message?.includes('Loading chunk') ||
     reason.message?.includes('ChunkLoadError'))
  ) {
    console.warn('🔄 Dynamic import failed, attempting recovery...', reason);
    
    // Clear caches and reload
    if ('caches' in window) {
      caches.keys().then(names => {
        names.forEach(name => caches.delete(name));
      }).finally(() => {
        (window as any).location.reload();
      });
    } else {
      (window as any).location.reload();
    }
    
    // Prevent the unhandled rejection
    event.preventDefault();
  }
});

// Enable deployment health checks in development
if (import.meta.env.DEV) {
  enableAutoHealthCheck();
}

ReactDOM.createRoot(document.getElementById('root')!).render(
  <React.StrictMode>
    <AuthProvider {...cognitoAuthConfig}>
      <ErrorBoundary>
        <App />
      </ErrorBoundary>
    </AuthProvider>
  </React.StrictMode>,
)
